# libmsec documentation for python.

import gettext

# localization
try:
    gettext.install('msec')
except IOError:
    _ = str

HELP = {


    'ALLOW_X_CONNECTIONS': _("Allow local users to connect to X server. Accepted arguments: yes (all connections are allowed), local (only local connection), no (no connection)."), 

    'CHECK_WRITABLE': _("Enable checking for files/directories writable by everybody."), 

    'ENABLE_CONSOLE_LOG': _("Log syslog messages on console terminal 12."), 

    'MAIL_EMPTY_CONTENT': _("Send mail reports even if no changes were detected."), 

    'BASE_LEVEL': _("Defines the base security level, on top of which the current configuration is based."), 

    'ACCEPT_BROADCASTED_ICMP_ECHO': _("Accept broadcasted ICMP echo."), 

    'CHECK_PERMS': _("Enable periodic permission checking for files specified in msec policy. If set to yes, the permissions are verified on every run. If set to enforce, incorrect permissions are restored to the ones specified in msec security policy."), 

    'ALLOW_XSERVER_TO_LISTEN': _("Allow X server to accept connections from network on tcp port 6000."), 

    'CHECK_CHKROOTKIT': _("Enable checking for known rootkits using chkrootkit."), 

    'CHECK_RPM_PACKAGES': _("Enable verification for changes in the installed RPM packages. This will notify you when new packages are installed or removed."), 

    'SHELL_HISTORY_SIZE': _("Set shell commands history size. A value of -1 means unlimited."), 

    'ALLOW_REBOOT': _("Allow system reboot and shutdown to local users."), 

    'ENABLE_PAM_ROOT_FROM_WHEEL': _("Allow root access without password for the members of the wheel group."), 

    'CHECK_FIREWALL': _("Enable checking for changes in firewall settings."), 

    'CHECK_SUID_ROOT': _("Enable checking for additions/removals of suid root files."), 

    'SYSLOG_WARN': _("Enables logging of periodic checks to system log."), 

    'ENABLE_AT_CRONTAB': _("Enable crontab and at for users. Put allowed users in /etc/cron.allow and /etc/at.allow (see man at(1) and crontab(1))."), 

    'CHECK_GROUPS': _("Enable checking for changes in system groups."), 

    'CHECK_PASSWD': _("Enable password-related checks, such as empty passwords and strange super-user accounts."), 

    'PASSWORD_HISTORY': _("Set the password history length to prevent password reuse. This is not supported by pam_tcb."), 

    'CHECK_SUID_MD5': _("Enable checksum verification for suid files."), 

    'SECURE_TMP': _("Use secure location for temporary files. If this parameter is set to 'yes', user home directory will be used for temporary files. Otherwise, /tmp will be used."), 

    'MAIL_USER': _("User email to receive security notifications."), 

    'USER_UMASK': _("Set the user umask."), 

    'ENABLE_PAM_WHEEL_FOR_SU': _("Allow only users in wheel group to su to root."), 

    'CHECK_SHADOW': _("Enable checking for empty passwords in /etc/shadow (man shadow(5))."), 

    'ALLOW_AUTOLOGIN': _("Allow autologin."), 

    'CHECK_USERS': _("Enable checking for changes in system users."), 

    'CHECK_UNOWNED': _("Enable checking for unowned files."), 

    'SHELL_TIMEOUT': _("Set the shell timeout. A value of zero means no timeout."), 

    'ALLOW_USER_LIST': _("Allow display managers (kdm and gdm) to display list of local users."), 

    'ENABLE_DNS_SPOOFING_PROTECTION': _("Enable name resolution spoofing protection."), 

    'ENABLE_STARTUP_PERMS': _("Enforce MSEC file directory permissions on system startup. If this parameter is set to 'enforce', system permissions will be enforced automatically, according to system security settings."), 

    'ALLOW_CURDIR_IN_PATH': _("Include current directory into user PATH by default"), 

    'CHECK_USER_FILES': _("Enable permission checking on users' files that should not be owned by someone else, or writable."), 

    'CREATE_SERVER_LINK': _("Creates the symlink /etc/security/msec/server to point to /etc/security/msec/server.SERVER_LEVEL. The /etc/security/msec/server is used by chkconfig --add to decide to add a service if it is present in the file during the installation of packages. By default, two presets are provided: local (which only enables local services) and remote (which also enables some remote services considered safe). Note that the allowed services must be placed manually into the server.SERVER_LEVEL files when necessary."), 

    'ENABLE_PASSWORD': _("Use password to authenticate users. Take EXTREME care when disabling passwords, as it will leave the machine vulnerable."), 

    'NOTIFY_WARN': _("Show security notifications in system tray using libnotify."), 

    'WIN_PARTS_UMASK': _("Set umask option for mounting vfat and ntfs partitions. If umask is '-1', default system umask is used."), 

    'CHECK_OPEN_PORT': _("Enable checking for open network ports."), 

    'ALLOW_ROOT_LOGIN': _("Allow direct root login on terminal."), 

    'CHECK_ON_BATTERY': _("Run security checks when machine is running on battery power."), 

    'CHECK_SHOSTS': _("Enable checking for dangerous options in users' .rhosts/.shosts files."), 

    'ALLOW_REMOTE_ROOT_LOGIN': _("Allow remote root login via sshd. If yes, login is allowed. If without-password, only public-key authentication logins are allowed. See sshd_config(5) man page for more information."), 

    'ENABLE_LOG_STRANGE_PACKETS': _("Enable logging of strange network packets."), 

    'ENABLE_SULOGIN': _("Ask for root password when going to single user level (man sulogin(8))."), 

    'ENABLE_IP_SPOOFING_PROTECTION': _("Enable IP spoofing protection."), 

    'FIX_UNOWNED': _("Fix owner and group of unowned files to use nobody/nogroup."), 

    'MAIL_WARN': _("Send security check results by email."), 

    'ALLOW_XAUTH_FROM_ROOT': _("Allow to export display when passing from the root account to the other users. See pam_xauth(8) for more details."), 

    'CHECK_SECURITY': _("Enable daily security checks."), 

    'ACCEPT_ICMP_ECHO': _("Accept ICMP echo."), 

    'PASSWORD_LENGTH': _("Set the password minimum length and minimum number of digit and minimum number of capitalized letters, using length,ndigits,nupper format."), 

    'AUTHORIZE_SERVICES': _("Allow full access to network services controlled by tcp_wrapper (see hosts.deny(5)). If yes, all services are allowed. If local, only connections to local services are authorized. If no, the services must be authorized manually in /etc/hosts.allow (see hosts.allow(5))."), 

    'CHECK_PROMISC': _("Activate ethernet cards promiscuity check."), 

    'ROOT_UMASK': _("Set the root umask."), 

    'ENABLE_MSEC_CRON': _("Perform hourly security check for changes in system configuration."), 

    'ENABLE_STARTUP_MSEC': _("Enforce MSEC settings on system startup"), 

    'TTY_WARN': _("Enable periodic security check results to terminal."), 

    'ACCEPT_BOGUS_ERROR_RESPONSES': _("Accept bogus IPv4 error messages."), 

    'CHECK_SGID': _("Enable checking for additions/removals of sgid files."), 

    'CHECK_RPM_INTEGRITY': _("Enable verification of integrity of installed RPM packages. This will notify you if checksums of the installed files were changed, showing separate results for binary and configuration files."), 
}

